@@ -496,7 +496,6 @@ static uint16_t eigrp_sequence_encode(struct eigrp *eigrp, struct stream *s)
 {
 	uint16_t length = EIGRP_TLV_SEQ_BASE_LEN;
 	struct eigrp_interface *ei;
-	struct listnode *node, *node2, *nnode2;
 	struct eigrp_neighbor *nbr;
 	size_t backup_end, size_end;
 	int found;
@@ -509,8 +508,8 @@ static uint16_t eigrp_sequence_encode(struct eigrp *eigrp, struct stream *s)
 	stream_putc(s, IPV4_MAX_BYTELEN);
 
 	found = 0;
-	for (ALL_LIST_ELEMENTS_RO(eigrp->eiflist, node, ei)) {
-		for (ALL_LIST_ELEMENTS(ei->nbrs, node2, nnode2, nbr)) {
+	frr_each (eigrp_interface_hash, &eigrp->eifs, ei) {
+		frr_each (eigrp_nbr_hash, &ei->nbr_hash_head, nbr) {
 			if (nbr->multicast_queue->count > 0) {
 				length += (uint16_t)stream_put_ipv4(
 					s, nbr->src.s_addr);
@@ -671,7 +670,7 @@ static struct eigrp_packet *eigrp_hello_encode(struct eigrp_interface *ei,
 		// Set packet length
 		ep->length = length;
 
-		// set soruce address for the hello packet
+		/* set destination for the packet */
 		ep->dst.s_addr = addr;
 
 		if ((ei->params.auth_type == EIGRP_AUTH_TYPE_MD5)
