@@ -140,38 +140,38 @@ struct ls_node {
 };
 
 /* Link State flags to indicate which Attribute parameters are valid */
-#define LS_ATTR_UNSET		0x00000000
-#define LS_ATTR_NAME		0x00000001
-#define LS_ATTR_METRIC		0x00000002
-#define LS_ATTR_TE_METRIC	0x00000004
-#define LS_ATTR_ADM_GRP		0x00000008
-#define LS_ATTR_LOCAL_ADDR	0x00000010
-#define LS_ATTR_NEIGH_ADDR	0x00000020
-#define LS_ATTR_LOCAL_ADDR6	0x00000040
-#define LS_ATTR_NEIGH_ADDR6	0x00000080
-#define LS_ATTR_LOCAL_ID	0x00000100
-#define LS_ATTR_NEIGH_ID	0x00000200
-#define LS_ATTR_MAX_BW		0x00000400
-#define LS_ATTR_MAX_RSV_BW	0x00000800
-#define LS_ATTR_UNRSV_BW	0x00001000
-#define LS_ATTR_REMOTE_AS	0x00002000
-#define LS_ATTR_REMOTE_ADDR	0x00004000
-#define LS_ATTR_REMOTE_ADDR6	0x00008000
-#define LS_ATTR_DELAY		0x00010000
-#define LS_ATTR_MIN_MAX_DELAY	0x00020000
-#define LS_ATTR_JITTER		0x00040000
-#define LS_ATTR_PACKET_LOSS	0x00080000
-#define LS_ATTR_AVA_BW		0x00100000
-#define LS_ATTR_RSV_BW		0x00200000
-#define LS_ATTR_USE_BW		0x00400000
-#define LS_ATTR_ADJ_SID		0x01000000
-#define LS_ATTR_BCK_ADJ_SID	0x02000000
-#define LS_ATTR_ADJ_SID6	0x04000000
-#define LS_ATTR_BCK_ADJ_SID6	0x08000000
-#define LS_ATTR_SRLG		0x10000000
-#define LS_ATTR_EXT_ADM_GRP 0x20000000
-#define LS_ATTR_ADJ_SRV6SID	0x40000000
-#define LS_ATTR_BCK_ADJ_SRV6SID 0x80000000
+#define LS_ATTR_UNSET		0x00000000U
+#define LS_ATTR_NAME		0x00000001U
+#define LS_ATTR_METRIC		0x00000002U
+#define LS_ATTR_TE_METRIC	0x00000004U
+#define LS_ATTR_ADM_GRP		0x00000008U
+#define LS_ATTR_LOCAL_ADDR	0x00000010U
+#define LS_ATTR_NEIGH_ADDR	0x00000020U
+#define LS_ATTR_LOCAL_ADDR6	0x00000040U
+#define LS_ATTR_NEIGH_ADDR6	0x00000080U
+#define LS_ATTR_LOCAL_ID	0x00000100U
+#define LS_ATTR_NEIGH_ID	0x00000200U
+#define LS_ATTR_MAX_BW		0x00000400U
+#define LS_ATTR_MAX_RSV_BW	0x00000800U
+#define LS_ATTR_UNRSV_BW	0x00001000U
+#define LS_ATTR_REMOTE_AS	0x00002000U
+#define LS_ATTR_REMOTE_ADDR	0x00004000U
+#define LS_ATTR_REMOTE_ADDR6	0x00008000U
+#define LS_ATTR_DELAY		0x00010000U
+#define LS_ATTR_MIN_MAX_DELAY	0x00020000U
+#define LS_ATTR_JITTER		0x00040000U
+#define LS_ATTR_PACKET_LOSS	0x00080000U
+#define LS_ATTR_AVA_BW		0x00100000U
+#define LS_ATTR_RSV_BW		0x00200000U
+#define LS_ATTR_USE_BW		0x00400000U
+#define LS_ATTR_ADJ_SID		0x01000000U
+#define LS_ATTR_BCK_ADJ_SID	0x02000000U
+#define LS_ATTR_ADJ_SID6	0x04000000U
+#define LS_ATTR_BCK_ADJ_SID6	0x08000000U
+#define LS_ATTR_SRLG		0x10000000U
+#define LS_ATTR_EXT_ADM_GRP	0x20000000U
+#define LS_ATTR_ADJ_SRV6SID	0x40000000U
+#define LS_ATTR_BCK_ADJ_SRV6SID 0x80000000U
 
 /* Link State Attributes */
 struct ls_attributes {
