@@ -207,8 +207,8 @@ void nexthop_change_labels(struct nexthop *nexthop, struct mpls_label_stack *new
 void nexthop_add_srv6_seg6local(struct nexthop *nexthop, uint32_t action,
 				const struct seg6local_context *ctx);
 void nexthop_del_srv6_seg6local(struct nexthop *nexthop);
-void nexthop_add_srv6_seg6(struct nexthop *nexthop, const struct in6_addr *seg,
-			   int num_segs);
+void nexthop_add_srv6_seg6(struct nexthop *nexthop, const struct in6_addr *seg, int num_segs,
+			   enum srv6_headend_behavior encap_behavior);
 void nexthop_del_srv6_seg6(struct nexthop *nexthop);
 
 /*
@@ -238,6 +238,7 @@ struct nexthop *nexthop_from_blackhole(enum blackhole_type bh_type,
 uint32_t nexthop_hash(const struct nexthop *nexthop);
 
 extern bool nexthop_same(const struct nexthop *nh1, const struct nexthop *nh2);
+extern bool nexthop_same_no_ifindex(const struct nexthop *nh1, const struct nexthop *nh2);
 extern bool nexthop_same_no_labels(const struct nexthop *nh1,
 				   const struct nexthop *nh2);
 extern int nexthop_cmp(const struct nexthop *nh1, const struct nexthop *nh2);
